#include "simple2-client.h"
#include "simple2-server.h"


static const CORBA::Long _oc_vec10[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    14, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x76656331), ACE_NTOHL(0x303a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:vec10:1.0 */,
    6, ACE_NTOHL(0x76656331), ACE_NTOHL(0x30000000) /* name = vec10 */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_long,
      10
};

static CORBA::TypeCode _tc_TAO_tc_vec10 (CORBA::tk_alias, sizeof(_oc_vec10), (char *) &_oc_vec10, 0, sizeof(vec10 ));

CORBA::TypeCode_ptr _tc_vec10 = &_tc_TAO_tc_vec10;


vec10::vec10()
  : _maximum(10),
    _length(0),
    _buffer(vec10::allocbuf(10)),
    _release(1)
{
}

vec10::vec10(CORBA::ULong length, CORBA::Long *buffer, CORBA::Boolean release)
  : _maximum(10),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

vec10::vec10(const vec10 &o)
  : _maximum(10),
    _length(o._length),
    _release(1)
{
  CORBA::Long  *tmp1 = vec10::allocbuf(this->_maximum);

  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, o._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  this->_buffer = tmp1;
}

vec10::~vec10()
{
  this->_deallocate_buffer();
}

vec10 &vec10::operator=(const vec10 &rhs)
{
  if( this == &rhs )
    return *this;

  if( this->_release )
  {
  

  }
  else
    this->_buffer = vec10::allocbuf(rhs._maximum);

  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Long  *tmp1 = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, rhs._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  return *this;
}

CORBA::Long &vec10::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  return tmp[i];
}

const CORBA::Long &vec10::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * const tmp = ACE_reinterpret_cast(CORBA::Long  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Long *vec10::allocbuf(CORBA::ULong size)
{
  CORBA::Long  *tmp;
  tmp = new CORBA::Long [size];
  return tmp;
}

void vec10::freebuf(CORBA::Long *buffer)
{
  delete [] buffer;
}

void vec10::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Long  *tmp = vec10::allocbuf(length);

  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Long  *old = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);

    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];

    if( this->_release )
      vec10::freebuf(old);
  }
  this->_buffer = tmp;
}

void vec10::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;

  CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);


  vec10::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean vec10::release() const
{
  return this->_release;
}

CORBA::ULong vec10::maximum() const
{
  return 10;
}

CORBA::ULong vec10::length() const
{
  return this->_length;
}

void vec10::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    return;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void vec10::_shrink_buffer(CORBA::ULong , CORBA::ULong )
{
}

CORBA::Long *vec10::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Long  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = vec10::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Long *vec10::get_buffer() const
{
  return ACE_const_cast(const CORBA::Long  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const vec10 &o)
{
  vec10  *_any_val;
  ACE_NEW(_any_val, vec10  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_vec10, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, vec10 *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_vec10, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, vec10 *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_vec10, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (vec10  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, vec10 , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_vec10, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_vec10, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

vec10_var::vec10_var()
  : ptr_(0)
{}

vec10_var::vec10_var(vec10 *p)
 : ptr_(p)
{}

vec10_var::vec10_var(const vec10_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new vec10 (*a.ptr_);
  else
    this->ptr_ = 0;
}

vec10_var::~vec10_var()
{
  delete this->ptr_;
}

vec10_var &vec10_var::operator=(vec10 *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

vec10_var &vec10_var::operator=(const vec10_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new vec10 (*p.ptr_);
  }
  return *this;
}

CORBA::Long &vec10_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &vec10_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

vec10 *vec10_var::operator->()
{
  return this->ptr_;
}

const vec10 *vec10_var::operator->() const
{
  return this->ptr_;
}

vec10_var::operator const vec10 &() const
{
  return *this->ptr_;
}

vec10_var::operator vec10 &()
{
  return *this->ptr_;
}

vec10_var::operator vec10 &() const
{
  return *this->ptr_;
}

const vec10 &vec10_var::in() const
{
  return *this->ptr_;
}

vec10 &vec10_var::inout()
{
  return *this->ptr_;
}

vec10 *&vec10_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

vec10 *vec10_var::_retn()
{
  vec10  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

vec10 *vec10_var::ptr() const
{
  return this->ptr_;
}

vec10_out::vec10_out(vec10 *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

vec10_out::vec10_out(vec10_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

vec10_out::vec10_out(const vec10_out &r)
  : ptr_(ACE_const_cast(vec10_out &,r).ptr_)
{}

vec10_out &vec10_out::operator=(const vec10_out &r)
{
  this->ptr_ = ACE_const_cast(vec10_out &,r).ptr_;
  return *this;
}

vec10_out &vec10_out::operator=(vec10 *r)
{
  this->ptr_ = r;
  return *this;
}

vec10_out::operator vec10 *&()
{
  return this->ptr_;
}

vec10 *&vec10_out::ptr()
{
  return this->ptr_;
}

CORBA::Long &vec10_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &vec10_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

vec10 *vec10_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_simple[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    15, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c653a31), ACE_NTOHL(0x2e300000) /* repository ID = IDL:simple:1.0 */,
    7, ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c650000) /* name = simple */
};

static CORBA::TypeCode _tc_TAO_tc_simple (CORBA::tk_objref, sizeof(_oc_simple), (char *) &_oc_simple, 0, sizeof(simple ));

CORBA::TypeCode_ptr _tc_simple = &_tc_TAO_tc_simple;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<simple , simple_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<simple , simple_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


simple_ptr  (*_TAO_collocation_simple_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


simple_ptr simple::_duplicate(simple_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

simple_ptr simple::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return simple::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:simple:1.0", _env);
  if (_env.exception() != 0)
    return simple::_nil();
  if (is_a == 0)
    return simple::_nil();
  return simple::_unchecked_narrow(obj, _env);
}

simple_ptr simple::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return simple::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && _TAO_collocation_simple_Stub_Factory_function_pointer != 0)
    {
      simple_ptr  retv = _TAO_collocation_simple_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new simple (stub);
}

simple_ptr simple::_nil()
{
  return (simple_ptr )NULL;
}

CORBA::Boolean simple::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:simple:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *simple::_interface_repository_id() const
{
  return "IDL:simple:1.0";
}

simple::simple()
{}

simple::~simple()
{}

void operator<<=(CORBA::Any &a, simple_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = simple::_duplicate(o);
    a.replace (_tc_simple, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, simple_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = simple::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_simple, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_simple, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = simple::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_simple, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

simple::simple(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

simple_var::simple_var()
  : ptr_(simple::_nil())
{}

simple_var::simple_var(simple_ptr p)
  : ptr_(p)
{}

simple_var::simple_var(const simple_var &a)
  : ptr_(simple::_duplicate(a.ptr()))
{}

simple_var::~simple_var()
{
  CORBA::release(this->ptr_);
}

simple_var &simple_var::operator=(simple_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

simple_var &simple_var::operator=(const simple_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = simple::_duplicate(p.ptr());
  }
  return *this;
}

simple_ptr simple_var::operator->() const
{
  return this->ptr_;
}

simple_var::operator const simple_ptr &() const
{
  return this->ptr_;
}

simple_var::operator simple_ptr &()
{
  return this->ptr_;
}

simple_ptr simple_var::in() const
{
  return this->ptr_;
}

simple_ptr &simple_var::inout()
{
  return this->ptr_;
}

simple_ptr &simple_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple::_nil();
  return this->ptr_;
}

simple_ptr simple_var::_retn()
{
  simple_ptr  val = this->ptr_;
  this->ptr_ = simple::_nil();
  return val;
}

simple_ptr simple_var::ptr() const
{
  return this->ptr_;
}

simple_out::simple_out(simple_ptr &r)
  : ptr_(r)
{
  this->ptr_ = simple::_nil();
}

simple_out::simple_out(simple_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple::_nil();
}

simple_out::simple_out(const simple_out &r)
  : ptr_(ACE_const_cast(simple_out &,r).ptr_)
{}

simple_out &simple_out::operator=(const simple_out &r)
{
  this->ptr_ = ACE_const_cast(simple_out &,r).ptr_;
  return *this;
}

simple_out &simple_out::operator=(const simple_var &r)
{
  this->ptr_ = simple::_duplicate(r.ptr());
  return *this;
}

simple_out &simple_out::operator=(simple_ptr r)
{
  this->ptr_ = r;
  return *this;
}

simple_out::operator simple_ptr &()
{
  return this->ptr_;
}

simple_ptr &simple_out::ptr()
{
  return this->ptr_;
}

simple_ptr simple_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_simple2[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    16, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c65323a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:simple2:1.0 */,
    8, ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c653200) /* name = simple2 */
};

static CORBA::TypeCode _tc_TAO_tc_simple2 (CORBA::tk_objref, sizeof(_oc_simple2), (char *) &_oc_simple2, 0, sizeof(simple2 ));

CORBA::TypeCode_ptr _tc_simple2 = &_tc_TAO_tc_simple2;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<simple2 , simple2_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<simple2 , simple2_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


simple2_ptr  (*_TAO_collocation_simple2_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


simple2_ptr simple2::_duplicate(simple2_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

simple2_ptr simple2::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return simple2::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:simple2:1.0", _env);
  if (_env.exception() != 0)
    return simple2::_nil();
  if (is_a == 0)
    return simple2::_nil();
  return simple2::_unchecked_narrow(obj, _env);
}

simple2_ptr simple2::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return simple2::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && _TAO_collocation_simple2_Stub_Factory_function_pointer != 0)
    {
      simple2_ptr  retv = _TAO_collocation_simple2_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new simple2 (stub);
}

simple2_ptr simple2::_nil()
{
  return (simple2_ptr )NULL;
}

CORBA::Boolean simple2::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:simple:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, "IDL:simple2:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *simple2::_interface_repository_id() const
{
  return "IDL:simple2:1.0";
}

simple2::simple2()
{}

simple2::~simple2()
{}

void operator<<=(CORBA::Any &a, simple2_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = simple2::_duplicate(o);
    a.replace (_tc_simple2, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, simple2_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = simple2::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_simple2, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_simple2, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = simple2::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_simple2, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

simple2::simple2(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

simple2_var::simple2_var()
  : ptr_(simple2::_nil())
{}

simple2_var::simple2_var(simple2_ptr p)
  : ptr_(p)
{}

simple2_var::simple2_var(const simple2_var &a)
  : ptr_(simple2::_duplicate(a.ptr()))
{}

simple2_var::~simple2_var()
{
  CORBA::release(this->ptr_);
}

simple2_var &simple2_var::operator=(simple2_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

simple2_var &simple2_var::operator=(const simple2_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = simple2::_duplicate(p.ptr());
  }
  return *this;
}

simple2_ptr simple2_var::operator->() const
{
  return this->ptr_;
}

simple2_var::operator const simple2_ptr &() const
{
  return this->ptr_;
}

simple2_var::operator simple2_ptr &()
{
  return this->ptr_;
}

simple2_ptr simple2_var::in() const
{
  return this->ptr_;
}

simple2_ptr &simple2_var::inout()
{
  return this->ptr_;
}

simple2_ptr &simple2_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple2::_nil();
  return this->ptr_;
}

simple2_ptr simple2_var::_retn()
{
  simple2_ptr  val = this->ptr_;
  this->ptr_ = simple2::_nil();
  return val;
}

simple2_ptr simple2_var::ptr() const
{
  return this->ptr_;
}

simple2_out::simple2_out(simple2_ptr &r)
  : ptr_(r)
{
  this->ptr_ = simple2::_nil();
}

simple2_out::simple2_out(simple2_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple2::_nil();
}

simple2_out::simple2_out(const simple2_out &r)
  : ptr_(ACE_const_cast(simple2_out &,r).ptr_)
{}

simple2_out &simple2_out::operator=(const simple2_out &r)
{
  this->ptr_ = ACE_const_cast(simple2_out &,r).ptr_;
  return *this;
}

simple2_out &simple2_out::operator=(const simple2_var &r)
{
  this->ptr_ = simple2::_duplicate(r.ptr());
  return *this;
}

simple2_out &simple2_out::operator=(simple2_ptr r)
{
  this->ptr_ = r;
  return *this;
}

simple2_out::operator simple2_ptr &()
{
  return this->ptr_;
}

simple2_ptr &simple2_out::ptr()
{
  return this->ptr_;
}

simple2_ptr simple2_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_simple3[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    16, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c65333a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:simple3:1.0 */,
    8, ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c653300) /* name = simple3 */
};

static CORBA::TypeCode _tc_TAO_tc_simple3 (CORBA::tk_objref, sizeof(_oc_simple3), (char *) &_oc_simple3, 0, sizeof(simple3 ));

CORBA::TypeCode_ptr _tc_simple3 = &_tc_TAO_tc_simple3;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<simple3 , simple3_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<simple3 , simple3_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


simple3_ptr  (*_TAO_collocation_simple3_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


simple3_ptr simple3::_duplicate(simple3_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

simple3_ptr simple3::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return simple3::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:simple3:1.0", _env);
  if (_env.exception() != 0)
    return simple3::_nil();
  if (is_a == 0)
    return simple3::_nil();
  return simple3::_unchecked_narrow(obj, _env);
}

simple3_ptr simple3::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return simple3::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && _TAO_collocation_simple3_Stub_Factory_function_pointer != 0)
    {
      simple3_ptr  retv = _TAO_collocation_simple3_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new simple3 (stub);
}

simple3_ptr simple3::_nil()
{
  return (simple3_ptr )NULL;
}

CORBA::Boolean simple3::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:simple:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, "IDL:simple2:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, "IDL:simple3:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *simple3::_interface_repository_id() const
{
  return "IDL:simple3:1.0";
}

simple3::simple3()
{}

simple3::~simple3()
{}

void operator<<=(CORBA::Any &a, simple3_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = simple3::_duplicate(o);
    a.replace (_tc_simple3, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, simple3_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = simple3::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_simple3, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_simple3, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = simple3::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_simple3, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

simple3::simple3(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

simple3_var::simple3_var()
  : ptr_(simple3::_nil())
{}

simple3_var::simple3_var(simple3_ptr p)
  : ptr_(p)
{}

simple3_var::simple3_var(const simple3_var &a)
  : ptr_(simple3::_duplicate(a.ptr()))
{}

simple3_var::~simple3_var()
{
  CORBA::release(this->ptr_);
}

simple3_var &simple3_var::operator=(simple3_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

simple3_var &simple3_var::operator=(const simple3_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = simple3::_duplicate(p.ptr());
  }
  return *this;
}

simple3_ptr simple3_var::operator->() const
{
  return this->ptr_;
}

simple3_var::operator const simple3_ptr &() const
{
  return this->ptr_;
}

simple3_var::operator simple3_ptr &()
{
  return this->ptr_;
}

simple3_ptr simple3_var::in() const
{
  return this->ptr_;
}

simple3_ptr &simple3_var::inout()
{
  return this->ptr_;
}

simple3_ptr &simple3_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple3::_nil();
  return this->ptr_;
}

simple3_ptr simple3_var::_retn()
{
  simple3_ptr  val = this->ptr_;
  this->ptr_ = simple3::_nil();
  return val;
}

simple3_ptr simple3_var::ptr() const
{
  return this->ptr_;
}

simple3_out::simple3_out(simple3_ptr &r)
  : ptr_(r)
{
  this->ptr_ = simple3::_nil();
}

simple3_out::simple3_out(simple3_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple3::_nil();
}

simple3_out::simple3_out(const simple3_out &r)
  : ptr_(ACE_const_cast(simple3_out &,r).ptr_)
{}

simple3_out &simple3_out::operator=(const simple3_out &r)
{
  this->ptr_ = ACE_const_cast(simple3_out &,r).ptr_;
  return *this;
}

simple3_out &simple3_out::operator=(const simple3_var &r)
{
  this->ptr_ = simple3::_duplicate(r.ptr());
  return *this;
}

simple3_out &simple3_out::operator=(simple3_ptr r)
{
  this->ptr_ = r;
  return *this;
}

simple3_out::operator simple3_ptr &()
{
  return this->ptr_;
}

simple3_ptr &simple3_out::ptr()
{
  return this->ptr_;
}

simple3_ptr simple3_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_simple3_OVERFLOW[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    25, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c65332f), ACE_NTOHL(0x4f564552), ACE_NTOHL(0x464c4f57), ACE_NTOHL(0x3a312e30), ACE_NTOHL(0x00000000) /* repository ID = IDL:simple3/OVERFLOW:1.0 */,
    9, ACE_NTOHL(0x4f564552), ACE_NTOHL(0x464c4f57), ACE_NTOHL(0x00000000) /* name = OVERFLOW */,
    2 /* member count */,
    2, ACE_NTOHL(0x61000000) /* name = a */,
    CORBA::tk_long,
    4, ACE_NTOHL(0x6d736700) /* name = msg */,
    CORBA::tk_string,
    0
};

static CORBA::TypeCode _tc_TAO_tc_simple3_OVERFLOW (CORBA::tk_except, sizeof(_oc_simple3_OVERFLOW), (char *) &_oc_simple3_OVERFLOW, 0, sizeof(::simple3::OVERFLOW ));

CORBA::TypeCode_ptr simple3::_tc_OVERFLOW = &_tc_TAO_tc_simple3_OVERFLOW;


simple3::OVERFLOW::OVERFLOW()
  : CORBA_UserException(simple3::_tc_OVERFLOW)
{
}

simple3::OVERFLOW::OVERFLOW(const ::simple3::OVERFLOW &o)
  : CORBA_UserException(o._type())
{
  this->a = o.a;
  this->msg = CORBA::string_dup(o.msg.in());
}

simple3::OVERFLOW::~OVERFLOW()
{}

::simple3::OVERFLOW &simple3::OVERFLOW::operator=(const ::simple3::OVERFLOW &o)
{
  this->CORBA_UserException::operator=(o);
  this->a = o.a;
  this->msg = CORBA::string_dup(o.msg.in());
  return *this;
}

void simple3::OVERFLOW::_raise()
{
  TAO_RAISE(*this);
}

::simple3::OVERFLOW *simple3::OVERFLOW::_narrow(CORBA::Exception *e)
{
  if( !(ACE_OS::strcmp("IDL:simple3/OVERFLOW:1.0", e->_id())) )
    return ACE_dynamic_cast(::simple3::OVERFLOW_ptr , e);
  else
    return 0;
}

CORBA::Exception *simple3::OVERFLOW::_alloc()
{
  return new ::simple3::OVERFLOW ;
}

simple3::OVERFLOW::OVERFLOW::OVERFLOW(CORBA::Long _a_, const char *_msg_)
  : CORBA_UserException(CORBA::TypeCode::_duplicate(simple3::_tc_OVERFLOW))
{
  this->a = _a_;
  this->msg = CORBA::string_dup(_msg_);
}

void operator<<=(CORBA::Any &a, const ::simple3::OVERFLOW &o)
{
  ::simple3::OVERFLOW  *_any_val = new ::simple3::OVERFLOW (o);
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(simple3::_tc_OVERFLOW, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::simple3::OVERFLOW *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(simple3::_tc_OVERFLOW, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::simple3::OVERFLOW *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(simple3::_tc_OVERFLOW, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::simple3::OVERFLOW  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::simple3::OVERFLOW , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(simple3::_tc_OVERFLOW, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(simple3::_tc_OVERFLOW, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

static const CORBA::Long _oc_simple3_UNDERFLOW[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    26, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c65332f), ACE_NTOHL(0x554e4445), ACE_NTOHL(0x52464c4f), ACE_NTOHL(0x573a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:simple3/UNDERFLOW:1.0 */,
    10, ACE_NTOHL(0x554e4445), ACE_NTOHL(0x52464c4f), ACE_NTOHL(0x57000000) /* name = UNDERFLOW */,
    2 /* member count */,
    2, ACE_NTOHL(0x62000000) /* name = b */,
    CORBA::tk_long,
    4, ACE_NTOHL(0x6d736700) /* name = msg */,
    CORBA::tk_string,
    0
};

static CORBA::TypeCode _tc_TAO_tc_simple3_UNDERFLOW (CORBA::tk_except, sizeof(_oc_simple3_UNDERFLOW), (char *) &_oc_simple3_UNDERFLOW, 0, sizeof(::simple3::UNDERFLOW ));

CORBA::TypeCode_ptr simple3::_tc_UNDERFLOW = &_tc_TAO_tc_simple3_UNDERFLOW;


simple3::UNDERFLOW::UNDERFLOW()
  : CORBA_UserException(simple3::_tc_UNDERFLOW)
{
}

simple3::UNDERFLOW::UNDERFLOW(const ::simple3::UNDERFLOW &o)
  : CORBA_UserException(o._type())
{
  this->b = o.b;
  this->msg = CORBA::string_dup(o.msg.in());
}

simple3::UNDERFLOW::~UNDERFLOW()
{}

::simple3::UNDERFLOW &simple3::UNDERFLOW::operator=(const ::simple3::UNDERFLOW &o)
{
  this->CORBA_UserException::operator=(o);
  this->b = o.b;
  this->msg = CORBA::string_dup(o.msg.in());
  return *this;
}

void simple3::UNDERFLOW::_raise()
{
  TAO_RAISE(*this);
}

::simple3::UNDERFLOW *simple3::UNDERFLOW::_narrow(CORBA::Exception *e)
{
  if( !(ACE_OS::strcmp("IDL:simple3/UNDERFLOW:1.0", e->_id())) )
    return ACE_dynamic_cast(::simple3::UNDERFLOW_ptr , e);
  else
    return 0;
}

CORBA::Exception *simple3::UNDERFLOW::_alloc()
{
  return new ::simple3::UNDERFLOW ;
}

simple3::UNDERFLOW::UNDERFLOW::UNDERFLOW(CORBA::Long _b_, const char *_msg_)
  : CORBA_UserException(CORBA::TypeCode::_duplicate(simple3::_tc_UNDERFLOW))
{
  this->b = _b_;
  this->msg = CORBA::string_dup(_msg_);
}

void operator<<=(CORBA::Any &a, const ::simple3::UNDERFLOW &o)
{
  ::simple3::UNDERFLOW  *_any_val = new ::simple3::UNDERFLOW (o);
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(simple3::_tc_UNDERFLOW, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::simple3::UNDERFLOW *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(simple3::_tc_UNDERFLOW, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::simple3::UNDERFLOW *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(simple3::_tc_UNDERFLOW, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::simple3::UNDERFLOW  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::simple3::UNDERFLOW , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(simple3::_tc_UNDERFLOW, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(simple3::_tc_UNDERFLOW, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

static const CORBA::Long _oc_simple3_BADNUM[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    23, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c65332f), ACE_NTOHL(0x4241444e), ACE_NTOHL(0x554d3a31), ACE_NTOHL(0x2e300000) /* repository ID = IDL:simple3/BADNUM:1.0 */,
    7, ACE_NTOHL(0x4241444e), ACE_NTOHL(0x554d0000) /* name = BADNUM */,
    1 /* member count */,
    2, ACE_NTOHL(0x63000000) /* name = c */,
    CORBA::tk_alias,
    56 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      14, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x76656331), ACE_NTOHL(0x303a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:vec10:1.0 */,
      6, ACE_NTOHL(0x76656331), ACE_NTOHL(0x30000000) /* name = vec10 */,
      CORBA::tk_sequence,
      12 /* encapsulation length */,
        TAO_ENCAP_BYTE_ORDER /* byte order */,
        CORBA::tk_long,
        10
};

static CORBA::TypeCode _tc_TAO_tc_simple3_BADNUM (CORBA::tk_except, sizeof(_oc_simple3_BADNUM), (char *) &_oc_simple3_BADNUM, 0, sizeof(::simple3::BADNUM ));

CORBA::TypeCode_ptr simple3::_tc_BADNUM = &_tc_TAO_tc_simple3_BADNUM;


simple3::BADNUM::BADNUM()
  : CORBA_UserException(simple3::_tc_BADNUM)
{
}

simple3::BADNUM::BADNUM(const ::simple3::BADNUM &o)
  : CORBA_UserException(o._type())
{
  this->c = o.c;
}

simple3::BADNUM::~BADNUM()
{}

::simple3::BADNUM &simple3::BADNUM::operator=(const ::simple3::BADNUM &o)
{
  this->CORBA_UserException::operator=(o);
  this->c = o.c;
  return *this;
}

void simple3::BADNUM::_raise()
{
  TAO_RAISE(*this);
}

::simple3::BADNUM *simple3::BADNUM::_narrow(CORBA::Exception *e)
{
  if( !(ACE_OS::strcmp("IDL:simple3/BADNUM:1.0", e->_id())) )
    return ACE_dynamic_cast(::simple3::BADNUM_ptr , e);
  else
    return 0;
}

CORBA::Exception *simple3::BADNUM::_alloc()
{
  return new ::simple3::BADNUM ;
}

simple3::BADNUM::BADNUM::BADNUM(const vec10 &_c_)
  : CORBA_UserException(CORBA::TypeCode::_duplicate(simple3::_tc_BADNUM))
{
  this->c = _c_;
}

void operator<<=(CORBA::Any &a, const ::simple3::BADNUM &o)
{
  ::simple3::BADNUM  *_any_val = new ::simple3::BADNUM (o);
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(simple3::_tc_BADNUM, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::simple3::BADNUM *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(simple3::_tc_BADNUM, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::simple3::BADNUM *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(simple3::_tc_BADNUM, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::simple3::BADNUM  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::simple3::BADNUM , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(simple3::_tc_BADNUM, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(simple3::_tc_BADNUM, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

static const CORBA::Long _oc_simple3_USERERROR[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    26, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c65332f), ACE_NTOHL(0x55534552), ACE_NTOHL(0x4552524f), ACE_NTOHL(0x523a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:simple3/USERERROR:1.0 */,
    10, ACE_NTOHL(0x55534552), ACE_NTOHL(0x4552524f), ACE_NTOHL(0x52000000) /* name = USERERROR */,
    1 /* member count */,
    7, ACE_NTOHL(0x72656173), ACE_NTOHL(0x6f6e0000) /* name = reason */,
    CORBA::tk_string,
    0
};

static CORBA::TypeCode _tc_TAO_tc_simple3_USERERROR (CORBA::tk_except, sizeof(_oc_simple3_USERERROR), (char *) &_oc_simple3_USERERROR, 0, sizeof(::simple3::USERERROR ));

CORBA::TypeCode_ptr simple3::_tc_USERERROR = &_tc_TAO_tc_simple3_USERERROR;


simple3::USERERROR::USERERROR()
  : CORBA_UserException(simple3::_tc_USERERROR)
{
}

simple3::USERERROR::USERERROR(const ::simple3::USERERROR &o)
  : CORBA_UserException(o._type())
{
  this->reason = CORBA::string_dup(o.reason.in());
}

simple3::USERERROR::~USERERROR()
{}

::simple3::USERERROR &simple3::USERERROR::operator=(const ::simple3::USERERROR &o)
{
  this->CORBA_UserException::operator=(o);
  this->reason = CORBA::string_dup(o.reason.in());
  return *this;
}

void simple3::USERERROR::_raise()
{
  TAO_RAISE(*this);
}

::simple3::USERERROR *simple3::USERERROR::_narrow(CORBA::Exception *e)
{
  if( !(ACE_OS::strcmp("IDL:simple3/USERERROR:1.0", e->_id())) )
    return ACE_dynamic_cast(::simple3::USERERROR_ptr , e);
  else
    return 0;
}

CORBA::Exception *simple3::USERERROR::_alloc()
{
  return new ::simple3::USERERROR ;
}

simple3::USERERROR::USERERROR::USERERROR(const char *_reason_)
  : CORBA_UserException(CORBA::TypeCode::_duplicate(simple3::_tc_USERERROR))
{
  this->reason = CORBA::string_dup(_reason_);
}

void operator<<=(CORBA::Any &a, const ::simple3::USERERROR &o)
{
  ::simple3::USERERROR  *_any_val = new ::simple3::USERERROR (o);
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(simple3::_tc_USERERROR, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::simple3::USERERROR *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(simple3::_tc_USERERROR, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::simple3::USERERROR *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(simple3::_tc_USERERROR, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::simple3::USERERROR  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::simple3::USERERROR , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(simple3::_tc_USERERROR, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(simple3::_tc_USERERROR, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}
CORBA::Long simple::op(/* simple *this, */ CORBA::Long a, simple_out b, CORBA::Long &c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort1);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 3, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_cdr_encode_signed32(16, c, CORBA::Long );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t1_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t1_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t1_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort14);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swapxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort14);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort14);
              flick_cdr_swap_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort14:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort15);
              break;
              {
              _flick_abort15:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort16);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort16:
                goto _flick_abort1;
              }
            }
          }
      }

    else
      {
        int _t0_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t0_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t0_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort7);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdrxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort7);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort7);
              flick_cdr_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort7:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort8);
              break;
              {
              _flick_abort8:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort9);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort9:
                goto _flick_abort1;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort1);
  }
  return _return;
  {
  _flick_abort1:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort0);
  _flick_abort0:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long simple2::op2(/* simple2 *this, */ CORBA::Long a, simple_ptr b, simple2_out c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort18);
    }




    {
      flick_iiopxx_encode_new_glob(16, _flick_abort18);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 4, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '2', flick_char8_t );
      flick_cdr_encode_char8(7, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
      flick_cdrxx_encode_IOR(iiopxx, b, 0, simple , _flick_abort18);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t3_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort18);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t3_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t3_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort31);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swapxx_decode_IOR(iiopxx, c, 1, simple2 , _flick_abort31);
              break;
              {
              _flick_abort31:
                goto _flick_abort18;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort32);
              break;
              {
              _flick_abort32:
                goto _flick_abort18;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort33);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort33:
                goto _flick_abort18;
              }
            }
          }
      }

    else
      {
        int _t2_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort18);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t2_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t2_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort24);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdrxx_decode_IOR(iiopxx, c, 1, simple2 , _flick_abort24);
              break;
              {
              _flick_abort24:
                goto _flick_abort18;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort25);
              break;
              {
              _flick_abort25:
                goto _flick_abort18;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort26);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort26:
                goto _flick_abort18;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort18);
  }
  return _return;
  {
  _flick_abort18:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort17);
  _flick_abort17:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long simple2::op(/* simple2 *this, */ CORBA::Long a, simple_out b, CORBA::Long &c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort35);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort35);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 3, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_cdr_encode_signed32(16, c, CORBA::Long );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort35);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t5_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort35);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t5_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t5_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort48);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swapxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort48);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort48);
              flick_cdr_swap_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort48:
                goto _flick_abort35;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort49);
              break;
              {
              _flick_abort49:
                goto _flick_abort35;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort50);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort50:
                goto _flick_abort35;
              }
            }
          }
      }

    else
      {
        int _t4_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort35);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t4_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t4_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort41);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdrxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort41);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort41);
              flick_cdr_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort41:
                goto _flick_abort35;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort42);
              break;
              {
              _flick_abort42:
                goto _flick_abort35;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort43);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort43:
                goto _flick_abort35;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort35);
  }
  return _return;
  {
  _flick_abort35:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort34);
  _flick_abort34:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long simple3::op3(/* simple3 *this, */ CORBA::Long a, simple3_out b, simple2_out c, simple_out d, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort52);
    }




    {
      flick_iiopxx_encode_new_glob(16, _flick_abort52);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 4, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '3', flick_char8_t );
      flick_cdr_encode_char8(7, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort52);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t105_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(76);
        flick_iiopxx_check_span(4, _flick_abort52);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t105_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t105_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort128);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(76);
              flick_cdr_swapxx_decode_IOR(iiopxx, b, 1, simple3 , _flick_abort128);
              flick_cdr_swapxx_decode_IOR(iiopxx, c, 1, simple2 , _flick_abort128);
              flick_cdr_swapxx_decode_IOR(iiopxx, d, 1, simple , _flick_abort128);
              break;
              {
              _flick_abort128:
                goto _flick_abort52;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(76);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort129);
              break;
              {
              _flick_abort129:
                goto _flick_abort52;
              }
            }
          default:
            {
              flick_corbaxx_env _t157_temp_env;
              unsigned int _t183_switch_tag;

              flick_iiopxx_check_span(32, _flick_abort130);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t183_switch_tag, unsigned int );
              flick_iiopxx_decode_end_chunk(4);
              switch ((unsigned int )_t183_switch_tag)
                {
                case (unsigned int) 25:
                  {
                    unsigned int _t184_switch_tag;

                    flick_iiopxx_check_span(36, _flick_abort130);
                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t184_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t184_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t185_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t185_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t185_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t186_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t186_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t186_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t187_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t187_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t187_switch_tag)
                                        {
                                        case /* OVER */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1331053906):
                                          {
                                            unsigned int _t188_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t188_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t188_switch_tag)
                                              {
                                              case /* FLOW */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1179406167):
                                                {
                                                  unsigned int _t189_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(4);
                                                  flick_cdr_decode_unsigned32(0, _t189_switch_tag, unsigned int );
                                                  flick_iiopxx_decode_end_chunk(4);
                                                  switch ((unsigned int )_t189_switch_tag)
                                                    {
                                                    case /* :1.0 */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 976301616):
                                                      {
                                                        char _t190_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(1);
                                                        flick_cdr_swap_decode_char8(0, _t190_switch_tag, char );
                                                        flick_iiopxx_decode_end_chunk(1);
                                                        switch ((char )_t190_switch_tag)
                                                          {
                                                          case 0:
                                                            {
                                                              flick_unsigned32_t _t191_temp_string_len;

                                                              _t157_temp_env._id = "IDL:simple3/OVERFLOW:1.0";
                                                              {
                                                                simple3::OVERFLOW *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::OVERFLOW *)new simple3::OVERFLOW ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort144);
                                                                _t157_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(11);
                                                              flick_cdr_swap_decode_signed32(3, ((simple3::OVERFLOW *)(_t157_temp_env._user_except))->a, CORBA::Long );
                                                              flick_cdr_swap_decode_unsigned32(7, _t191_temp_string_len, flick_unsigned32_t );
                                                              flick_iiopxx_decode_end_chunk(11);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              flick_iiopxx_decode_new_glob(1 * _t191_temp_string_len);
                                                              flick_iiopxx_check_span(1 * _t191_temp_string_len, _flick_abort144);
                                                              flick_iiopxx_decode_new_chunk(1 * _t191_temp_string_len);
                                                              {
                                                                CORBA::Char *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t191_temp_string_len * sizeof(CORBA::Char )));
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort144);
                                                                ((simple3::OVERFLOW *)(_t157_temp_env._user_except))->msg.inout() = _t_alloc_ptr;
                                                              }
                                                              flick_cdr_swap_decode_bcopy(0, ((simple3::OVERFLOW *)(_t157_temp_env._user_except))->msg.inout(), 1 * _t191_temp_string_len);
                                                              flick_iiopxx_decode_end_chunk(1 * _t191_temp_string_len);
                                                              flick_iiopxx_decode_end_glob(1 * _t191_temp_string_len);
                                                              break;
                                                              {
                                                              _flick_abort144:
                                                                goto _flick_abort130;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                        flick_iiopxx_decode_end_glob(76);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                  flick_iiopxx_decode_end_glob(76);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                            flick_iiopxx_decode_end_glob(76);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                      flick_iiopxx_decode_end_glob(76);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                flick_iiopxx_decode_end_glob(76);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                          flick_iiopxx_decode_end_glob(76);
                          break;
                        }
                      }
                    break;
                  }
                case (unsigned int) 26:
                  {
                    unsigned int _t192_switch_tag;

                    flick_iiopxx_check_span(36, _flick_abort130);
                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t192_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t192_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t193_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t193_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t193_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t194_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t194_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t194_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t195_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t195_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t195_switch_tag)
                                        {
                                        case /* UNDE */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1431192645):
                                          {
                                            unsigned int _t196_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t196_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t196_switch_tag)
                                              {
                                              case /* RFLO */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1380338767):
                                                {
                                                  unsigned int _t197_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(4);
                                                  flick_cdr_decode_unsigned32(0, _t197_switch_tag, unsigned int );
                                                  flick_iiopxx_decode_end_chunk(4);
                                                  switch ((unsigned int )_t197_switch_tag)
                                                    {
                                                    case /* W:1. */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1463431470):
                                                      {
                                                        unsigned short int _t198_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(2);
                                                        flick_cdr_decode_unsigned16(0, _t198_switch_tag, unsigned short int );
                                                        flick_iiopxx_decode_end_chunk(2);
                                                        switch ((unsigned short int )_t198_switch_tag)
                                                          {
                                                          case /* 0 */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 12288):
                                                            {
                                                              flick_unsigned32_t _t199_temp_string_len;

                                                              _t157_temp_env._id = "IDL:simple3/UNDERFLOW:1.0";
                                                              {
                                                                simple3::UNDERFLOW *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::UNDERFLOW *)new simple3::UNDERFLOW ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort147);
                                                                _t157_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(10);
                                                              flick_cdr_swap_decode_signed32(2, ((simple3::UNDERFLOW *)(_t157_temp_env._user_except))->b, CORBA::Long );
                                                              flick_cdr_swap_decode_unsigned32(6, _t199_temp_string_len, flick_unsigned32_t );
                                                              flick_iiopxx_decode_end_chunk(10);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              flick_iiopxx_decode_new_glob(1 * _t199_temp_string_len);
                                                              flick_iiopxx_check_span(1 * _t199_temp_string_len, _flick_abort147);
                                                              flick_iiopxx_decode_new_chunk(1 * _t199_temp_string_len);
                                                              {
                                                                CORBA::Char *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t199_temp_string_len * sizeof(CORBA::Char )));
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort147);
                                                                ((simple3::UNDERFLOW *)(_t157_temp_env._user_except))->msg.inout() = _t_alloc_ptr;
                                                              }
                                                              flick_cdr_swap_decode_bcopy(0, ((simple3::UNDERFLOW *)(_t157_temp_env._user_except))->msg.inout(), 1 * _t199_temp_string_len);
                                                              flick_iiopxx_decode_end_chunk(1 * _t199_temp_string_len);
                                                              flick_iiopxx_decode_end_glob(1 * _t199_temp_string_len);
                                                              break;
                                                              {
                                                              _flick_abort147:
                                                                goto _flick_abort130;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                        flick_iiopxx_decode_end_glob(76);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                  flick_iiopxx_decode_end_glob(76);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                            flick_iiopxx_decode_end_glob(76);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                      flick_iiopxx_decode_end_glob(76);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                flick_iiopxx_decode_end_glob(76);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                          flick_iiopxx_decode_end_glob(76);
                          break;
                        }
                      }
                    break;
                  }
                case (unsigned int) 23:
                  {
                    unsigned int _t200_switch_tag;

                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t200_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t200_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t201_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t201_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t201_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t202_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t202_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t202_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t203_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t203_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t203_switch_tag)
                                        {
                                        case /* BADN */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1111573582):
                                          {
                                            unsigned int _t204_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t204_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t204_switch_tag)
                                              {
                                              case /* UM:1 */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1431124529):
                                                {
                                                  unsigned short int _t205_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(2);
                                                  flick_cdr_decode_unsigned16(0, _t205_switch_tag, unsigned short int );
                                                  flick_iiopxx_decode_end_chunk(2);
                                                  switch ((unsigned short int )_t205_switch_tag)
                                                    {
                                                    case /* .0 */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 11824):
                                                      {
                                                        char _t206_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(1);
                                                        flick_cdr_swap_decode_char8(0, _t206_switch_tag, char );
                                                        flick_iiopxx_decode_end_chunk(1);
                                                        switch ((char )_t206_switch_tag)
                                                          {
                                                          case 0:
                                                            {
                                                              CORBA::ULong _t207_array_iter;

                                                              _t157_temp_env._id = "IDL:simple3/BADNUM:1.0";
                                                              {
                                                                simple3::BADNUM *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::BADNUM *)new simple3::BADNUM ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort150);
                                                                _t157_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(5);
                                                              flick_cdr_swap_decode_unsigned32(1, ((simple3::BADNUM *)(_t157_temp_env._user_except))->c._length, CORBA::ULong );
                                                              flick_iiopxx_decode_end_chunk(5);
                                                              if (((simple3::BADNUM *)(_t157_temp_env._user_except))->c._length > 10)
                                                                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort150);
                                                              {
                                                                CORBA::Long *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [10]);
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort150);
                                                                ((simple3::BADNUM *)(_t157_temp_env._user_except))->c._buffer = _t_alloc_ptr;
                                                                ((simple3::BADNUM *)(_t157_temp_env._user_except))->c._maximum = 10;
                                                                ((simple3::BADNUM *)(_t157_temp_env._user_except))->c._release = 1;
                                                              }
                                                              flick_iiopxx_check_span(((simple3::BADNUM *)(_t157_temp_env._user_except))->c._length * 4, _flick_abort150);
                                                              for (_t207_array_iter = 0; _t207_array_iter < ((simple3::BADNUM *)(_t157_temp_env._user_except))->c._length; _t207_array_iter++)
                                                                {
                                                                  flick_iiopxx_decode_new_chunk(4);
                                                                  flick_cdr_swap_decode_signed32(0, ((simple3::BADNUM *)(_t157_temp_env._user_except))->c._buffer[_t207_array_iter], CORBA::Long );
                                                                  flick_iiopxx_decode_end_chunk(4);
                                                                  continue;
                                                                }
                                                              flick_iiopxx_decode_end_glob(76);
                                                              break;
                                                              {
                                                              _flick_abort150:
                                                                goto _flick_abort130;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                        flick_iiopxx_decode_end_glob(76);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                                  flick_iiopxx_decode_end_glob(76);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                            flick_iiopxx_decode_end_glob(76);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                      flick_iiopxx_decode_end_glob(76);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                                flick_iiopxx_decode_end_glob(76);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                          flick_iiopxx_decode_end_glob(76);
                          break;
                        }
                      }
                    break;
                  }
                default:
                  {
                    flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort130);
                    flick_iiopxx_decode_end_glob(76);
                    break;
                  }
                }
              flick_corbaxx_exception_to_env(CORBA::Environment &, _ev, flick_corbaxx_env , _t157_temp_env);
              break;
              {
              _flick_abort130:
                goto _flick_abort52;
              }
            }
          }
      }

    else
      {
        int _t6_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(76);
        flick_iiopxx_check_span(4, _flick_abort52);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t6_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t6_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort77);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(76);
              flick_cdrxx_decode_IOR(iiopxx, b, 1, simple3 , _flick_abort77);
              flick_cdrxx_decode_IOR(iiopxx, c, 1, simple2 , _flick_abort77);
              flick_cdrxx_decode_IOR(iiopxx, d, 1, simple , _flick_abort77);
              break;
              {
              _flick_abort77:
                goto _flick_abort52;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(76);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort78);
              break;
              {
              _flick_abort78:
                goto _flick_abort52;
              }
            }
          default:
            {
              flick_corbaxx_env _t56_temp_env;
              unsigned int _t81_switch_tag;

              flick_iiopxx_check_span(32, _flick_abort79);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t81_switch_tag, unsigned int );
              flick_iiopxx_decode_end_chunk(4);
              switch ((unsigned int )_t81_switch_tag)
                {
                case (unsigned int) 25:
                  {
                    unsigned int _t82_switch_tag;

                    flick_iiopxx_check_span(36, _flick_abort79);
                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t82_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t82_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t83_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t83_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t83_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t84_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t84_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t84_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t85_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t85_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t85_switch_tag)
                                        {
                                        case /* OVER */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1331053906):
                                          {
                                            unsigned int _t86_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t86_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t86_switch_tag)
                                              {
                                              case /* FLOW */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1179406167):
                                                {
                                                  unsigned int _t87_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(4);
                                                  flick_cdr_decode_unsigned32(0, _t87_switch_tag, unsigned int );
                                                  flick_iiopxx_decode_end_chunk(4);
                                                  switch ((unsigned int )_t87_switch_tag)
                                                    {
                                                    case /* :1.0 */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 976301616):
                                                      {
                                                        char _t88_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(1);
                                                        flick_cdr_decode_char8(0, _t88_switch_tag, char );
                                                        flick_iiopxx_decode_end_chunk(1);
                                                        switch ((char )_t88_switch_tag)
                                                          {
                                                          case 0:
                                                            {
                                                              flick_unsigned32_t _t89_temp_string_len;

                                                              _t56_temp_env._id = "IDL:simple3/OVERFLOW:1.0";
                                                              {
                                                                simple3::OVERFLOW *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::OVERFLOW *)new simple3::OVERFLOW ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort90);
                                                                _t56_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(11);
                                                              flick_cdr_decode_signed32(3, ((simple3::OVERFLOW *)(_t56_temp_env._user_except))->a, CORBA::Long );
                                                              flick_cdr_decode_unsigned32(7, _t89_temp_string_len, flick_unsigned32_t );
                                                              flick_iiopxx_decode_end_chunk(11);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              flick_iiopxx_decode_new_glob(1 * _t89_temp_string_len);
                                                              flick_iiopxx_check_span(1 * _t89_temp_string_len, _flick_abort90);
                                                              flick_iiopxx_decode_new_chunk(1 * _t89_temp_string_len);
                                                              {
                                                                CORBA::Char *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t89_temp_string_len * sizeof(CORBA::Char )));
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort90);
                                                                ((simple3::OVERFLOW *)(_t56_temp_env._user_except))->msg.inout() = _t_alloc_ptr;
                                                              }
                                                              flick_cdr_decode_bcopy(0, ((simple3::OVERFLOW *)(_t56_temp_env._user_except))->msg.inout(), 1 * _t89_temp_string_len);
                                                              flick_iiopxx_decode_end_chunk(1 * _t89_temp_string_len);
                                                              flick_iiopxx_decode_end_glob(1 * _t89_temp_string_len);
                                                              break;
                                                              {
                                                              _flick_abort90:
                                                                goto _flick_abort79;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                        flick_iiopxx_decode_end_glob(76);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                  flick_iiopxx_decode_end_glob(76);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                            flick_iiopxx_decode_end_glob(76);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                      flick_iiopxx_decode_end_glob(76);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                flick_iiopxx_decode_end_glob(76);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                          flick_iiopxx_decode_end_glob(76);
                          break;
                        }
                      }
                    break;
                  }
                case (unsigned int) 26:
                  {
                    unsigned int _t90_switch_tag;

                    flick_iiopxx_check_span(36, _flick_abort79);
                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t90_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t90_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t91_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t91_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t91_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t92_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t92_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t92_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t93_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t93_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t93_switch_tag)
                                        {
                                        case /* UNDE */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1431192645):
                                          {
                                            unsigned int _t94_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t94_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t94_switch_tag)
                                              {
                                              case /* RFLO */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1380338767):
                                                {
                                                  unsigned int _t95_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(4);
                                                  flick_cdr_decode_unsigned32(0, _t95_switch_tag, unsigned int );
                                                  flick_iiopxx_decode_end_chunk(4);
                                                  switch ((unsigned int )_t95_switch_tag)
                                                    {
                                                    case /* W:1. */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1463431470):
                                                      {
                                                        unsigned short int _t96_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(2);
                                                        flick_cdr_decode_unsigned16(0, _t96_switch_tag, unsigned short int );
                                                        flick_iiopxx_decode_end_chunk(2);
                                                        switch ((unsigned short int )_t96_switch_tag)
                                                          {
                                                          case /* 0 */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 12288):
                                                            {
                                                              flick_unsigned32_t _t97_temp_string_len;

                                                              _t56_temp_env._id = "IDL:simple3/UNDERFLOW:1.0";
                                                              {
                                                                simple3::UNDERFLOW *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::UNDERFLOW *)new simple3::UNDERFLOW ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort93);
                                                                _t56_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(10);
                                                              flick_cdr_decode_signed32(2, ((simple3::UNDERFLOW *)(_t56_temp_env._user_except))->b, CORBA::Long );
                                                              flick_cdr_decode_unsigned32(6, _t97_temp_string_len, flick_unsigned32_t );
                                                              flick_iiopxx_decode_end_chunk(10);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              flick_iiopxx_decode_new_glob(1 * _t97_temp_string_len);
                                                              flick_iiopxx_check_span(1 * _t97_temp_string_len, _flick_abort93);
                                                              flick_iiopxx_decode_new_chunk(1 * _t97_temp_string_len);
                                                              {
                                                                CORBA::Char *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t97_temp_string_len * sizeof(CORBA::Char )));
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort93);
                                                                ((simple3::UNDERFLOW *)(_t56_temp_env._user_except))->msg.inout() = _t_alloc_ptr;
                                                              }
                                                              flick_cdr_decode_bcopy(0, ((simple3::UNDERFLOW *)(_t56_temp_env._user_except))->msg.inout(), 1 * _t97_temp_string_len);
                                                              flick_iiopxx_decode_end_chunk(1 * _t97_temp_string_len);
                                                              flick_iiopxx_decode_end_glob(1 * _t97_temp_string_len);
                                                              break;
                                                              {
                                                              _flick_abort93:
                                                                goto _flick_abort79;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                        flick_iiopxx_decode_end_glob(76);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                  flick_iiopxx_decode_end_glob(76);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                            flick_iiopxx_decode_end_glob(76);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                      flick_iiopxx_decode_end_glob(76);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                flick_iiopxx_decode_end_glob(76);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                          flick_iiopxx_decode_end_glob(76);
                          break;
                        }
                      }
                    break;
                  }
                case (unsigned int) 23:
                  {
                    unsigned int _t98_switch_tag;

                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t98_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t98_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t99_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t99_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t99_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t100_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t100_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t100_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t101_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t101_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t101_switch_tag)
                                        {
                                        case /* BADN */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1111573582):
                                          {
                                            unsigned int _t102_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t102_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t102_switch_tag)
                                              {
                                              case /* UM:1 */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1431124529):
                                                {
                                                  unsigned short int _t103_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(2);
                                                  flick_cdr_decode_unsigned16(0, _t103_switch_tag, unsigned short int );
                                                  flick_iiopxx_decode_end_chunk(2);
                                                  switch ((unsigned short int )_t103_switch_tag)
                                                    {
                                                    case /* .0 */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 11824):
                                                      {
                                                        char _t104_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(1);
                                                        flick_cdr_decode_char8(0, _t104_switch_tag, char );
                                                        flick_iiopxx_decode_end_chunk(1);
                                                        switch ((char )_t104_switch_tag)
                                                          {
                                                          case 0:
                                                            {
                                                              _t56_temp_env._id = "IDL:simple3/BADNUM:1.0";
                                                              {
                                                                simple3::BADNUM *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::BADNUM *)new simple3::BADNUM ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort96);
                                                                _t56_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(5);
                                                              flick_cdr_decode_unsigned32(1, ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._length, CORBA::ULong );
                                                              if (((simple3::BADNUM *)(_t56_temp_env._user_except))->c._length > 10)
                                                                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort96);
                                                              flick_iiopxx_decode_end_chunk(5);
                                                              flick_iiopxx_check_span(4 * ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._length, _flick_abort96);
                                                              flick_iiopxx_decode_new_chunk(4 * ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._length);
                                                              {
                                                                CORBA::Long *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [10]);
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort96);
                                                                ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._buffer = _t_alloc_ptr;
                                                                ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._maximum = 10;
                                                                ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._release = 1;
                                                              }
                                                              flick_cdr_decode_bcopy(0, ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._buffer, 4 * ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._length);
                                                              flick_iiopxx_decode_end_chunk(4 * ((simple3::BADNUM *)(_t56_temp_env._user_except))->c._length);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              break;
                                                              {
                                                              _flick_abort96:
                                                                goto _flick_abort79;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                              flick_iiopxx_decode_end_glob(76);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                        flick_iiopxx_decode_end_glob(76);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                                  flick_iiopxx_decode_end_glob(76);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                            flick_iiopxx_decode_end_glob(76);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                      flick_iiopxx_decode_end_glob(76);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                                flick_iiopxx_decode_end_glob(76);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                          flick_iiopxx_decode_end_glob(76);
                          break;
                        }
                      }
                    break;
                  }
                default:
                  {
                    flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort79);
                    flick_iiopxx_decode_end_glob(76);
                    break;
                  }
                }
              flick_corbaxx_exception_to_env(CORBA::Environment &, _ev, flick_corbaxx_env , _t56_temp_env);
              break;
              {
              _flick_abort79:
                goto _flick_abort52;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort52);
  }
  return _return;
  {
  _flick_abort52:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort51);
  _flick_abort51:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

char *simple3::op4(/* simple3 *this, */ const char *x, char *&y, ::CORBA::String_out z, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  char *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort157);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort157);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort157);
    }




    {
      flick_unsigned32_t _t210_temp_string_len;
      flick_unsigned32_t _t211_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, (x), flick_unsigned32_t , _t210_temp_string_len);
      flick_cdr_stringlen(CORBA::Char *, (y), flick_unsigned32_t , _t211_temp_string_len);

      flick_iiopxx_encode_new_glob(16, _flick_abort157);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 4, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '4', flick_char8_t );
      flick_cdr_encode_char8(7, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(12, _t210_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
      flick_iiopxx_encode_new_glob(1 * _t210_temp_string_len, _flick_abort157);
      flick_iiopxx_encode_new_chunk(1 * _t210_temp_string_len);
      flick_cdr_encode_bcopy(0, (x), 1 * _t210_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t210_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t210_temp_string_len);
      flick_iiopxx_encode_new_glob(7, _flick_abort157);
      flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
      flick_cdr_encode_unsigned32(0, _t211_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(4);
      flick_iiopxx_encode_end_glob(7);
      flick_iiopxx_encode_new_glob(1 * _t211_temp_string_len, _flick_abort157);
      flick_iiopxx_encode_new_chunk(1 * _t211_temp_string_len);
      flick_cdr_encode_bcopy(0, (y), 1 * _t211_temp_string_len);
      CORBA_string_flick_free((y));
      (y) = (CORBA::Char *)0;
      flick_iiopxx_encode_end_chunk(1 * _t211_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t211_temp_string_len);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort157);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort157);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort157);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort157);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t257_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(44);
        flick_iiopxx_check_span(4, _flick_abort157);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t257_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t257_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t280_temp_string_len;
              flick_unsigned32_t _t281_temp_string_len;
              flick_unsigned32_t _t282_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort226);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t280_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(44);
              flick_iiopxx_decode_new_glob(1 * _t280_temp_string_len);
              flick_iiopxx_check_span(1 * _t280_temp_string_len, _flick_abort226);
              flick_iiopxx_decode_new_chunk(1 * _t280_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t280_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort226);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t280_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t280_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t280_temp_string_len);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort229);
              flick_cdr_swap_decode_unsigned32(0, _t281_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              flick_iiopxx_decode_new_glob(1 * _t281_temp_string_len);
              flick_iiopxx_check_span(1 * _t281_temp_string_len, _flick_abort229);
              flick_iiopxx_decode_new_chunk(1 * _t281_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t281_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort229);
                y = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, y, 1 * _t281_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t281_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t281_temp_string_len);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort232);
              flick_cdr_swap_decode_unsigned32(0, _t282_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              flick_iiopxx_decode_new_glob(1 * _t282_temp_string_len);
              flick_iiopxx_check_span(1 * _t282_temp_string_len, _flick_abort232);
              flick_iiopxx_decode_new_chunk(1 * _t282_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t282_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort232);
                z = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, z, 1 * _t282_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t282_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t282_temp_string_len);
              break;
              {
              _flick_abort232:
                CORBA_string_flick_free(y);
              _flick_abort229:
                CORBA_string_flick_free(_return);
              _flick_abort226:
                goto _flick_abort157;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(44);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort236);
              break;
              {
              _flick_abort236:
                goto _flick_abort157;
              }
            }
          default:
            {
              flick_corbaxx_env _t283_temp_env;
              unsigned int _t293_switch_tag;

              flick_iiopxx_check_span(40, _flick_abort237);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t293_switch_tag, unsigned int );
              flick_iiopxx_decode_end_chunk(4);
              switch ((unsigned int )_t293_switch_tag)
                {
                case (unsigned int) 26:
                  {
                    unsigned int _t294_switch_tag;

                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t294_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t294_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t295_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t295_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t295_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t296_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t296_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t296_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t297_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t297_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t297_switch_tag)
                                        {
                                        case /* UNDE */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1431192645):
                                          {
                                            unsigned int _t298_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t298_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t298_switch_tag)
                                              {
                                              case /* RFLO */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1380338767):
                                                {
                                                  unsigned int _t299_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(4);
                                                  flick_cdr_decode_unsigned32(0, _t299_switch_tag, unsigned int );
                                                  flick_iiopxx_decode_end_chunk(4);
                                                  switch ((unsigned int )_t299_switch_tag)
                                                    {
                                                    case /* W:1. */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1463431470):
                                                      {
                                                        unsigned short int _t300_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(2);
                                                        flick_cdr_decode_unsigned16(0, _t300_switch_tag, unsigned short int );
                                                        flick_iiopxx_decode_end_chunk(2);
                                                        switch ((unsigned short int )_t300_switch_tag)
                                                          {
                                                          case /* 0 */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 12288):
                                                            {
                                                              flick_unsigned32_t _t301_temp_string_len;

                                                              _t283_temp_env._id = "IDL:simple3/UNDERFLOW:1.0";
                                                              {
                                                                simple3::UNDERFLOW *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::UNDERFLOW *)new simple3::UNDERFLOW ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort242);
                                                                _t283_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(10);
                                                              flick_cdr_swap_decode_signed32(2, ((simple3::UNDERFLOW *)(_t283_temp_env._user_except))->b, CORBA::Long );
                                                              flick_cdr_swap_decode_unsigned32(6, _t301_temp_string_len, flick_unsigned32_t );
                                                              flick_iiopxx_decode_end_chunk(10);
                                                              flick_iiopxx_decode_end_glob(44);
                                                              flick_iiopxx_decode_new_glob(1 * _t301_temp_string_len);
                                                              flick_iiopxx_check_span(1 * _t301_temp_string_len, _flick_abort242);
                                                              flick_iiopxx_decode_new_chunk(1 * _t301_temp_string_len);
                                                              {
                                                                CORBA::Char *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t301_temp_string_len * sizeof(CORBA::Char )));
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort242);
                                                                ((simple3::UNDERFLOW *)(_t283_temp_env._user_except))->msg.inout() = _t_alloc_ptr;
                                                              }
                                                              flick_cdr_swap_decode_bcopy(0, ((simple3::UNDERFLOW *)(_t283_temp_env._user_except))->msg.inout(), 1 * _t301_temp_string_len);
                                                              flick_iiopxx_decode_end_chunk(1 * _t301_temp_string_len);
                                                              flick_iiopxx_decode_end_glob(1 * _t301_temp_string_len);
                                                              break;
                                                              {
                                                              _flick_abort242:
                                                                goto _flick_abort237;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort237);
                                                              flick_iiopxx_decode_end_glob(44);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort237);
                                                        flick_iiopxx_decode_end_glob(44);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort237);
                                                  flick_iiopxx_decode_end_glob(44);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort237);
                                            flick_iiopxx_decode_end_glob(44);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort237);
                                      flick_iiopxx_decode_end_glob(44);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort237);
                                flick_iiopxx_decode_end_glob(44);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort237);
                          flick_iiopxx_decode_end_glob(44);
                          break;
                        }
                      }
                    break;
                  }
                default:
                  {
                    flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort237);
                    flick_iiopxx_decode_end_glob(44);
                    break;
                  }
                }
              flick_corbaxx_exception_to_env(CORBA::Environment &, _ev, flick_corbaxx_env , _t283_temp_env);
              break;
              {
              _flick_abort237:
                goto _flick_abort157;
              }
            }
          }
      }

    else
      {
        int _t212_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(44);
        flick_iiopxx_check_span(4, _flick_abort157);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t212_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t212_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t235_temp_string_len;
              flick_unsigned32_t _t236_temp_string_len;
              flick_unsigned32_t _t237_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort187);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t235_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(44);
              flick_iiopxx_decode_new_glob(1 * _t235_temp_string_len);
              flick_iiopxx_check_span(1 * _t235_temp_string_len, _flick_abort187);
              flick_iiopxx_decode_new_chunk(1 * _t235_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t235_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort187);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t235_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t235_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t235_temp_string_len);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort190);
              flick_cdr_decode_unsigned32(0, _t236_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              flick_iiopxx_decode_new_glob(1 * _t236_temp_string_len);
              flick_iiopxx_check_span(1 * _t236_temp_string_len, _flick_abort190);
              flick_iiopxx_decode_new_chunk(1 * _t236_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t236_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort190);
                y = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, y, 1 * _t236_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t236_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t236_temp_string_len);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort193);
              flick_cdr_decode_unsigned32(0, _t237_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              flick_iiopxx_decode_new_glob(1 * _t237_temp_string_len);
              flick_iiopxx_check_span(1 * _t237_temp_string_len, _flick_abort193);
              flick_iiopxx_decode_new_chunk(1 * _t237_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t237_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort193);
                z = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, z, 1 * _t237_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t237_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t237_temp_string_len);
              break;
              {
              _flick_abort193:
                CORBA_string_flick_free(y);
              _flick_abort190:
                CORBA_string_flick_free(_return);
              _flick_abort187:
                goto _flick_abort157;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(44);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort197);
              break;
              {
              _flick_abort197:
                goto _flick_abort157;
              }
            }
          default:
            {
              flick_corbaxx_env _t238_temp_env;
              unsigned int _t248_switch_tag;

              flick_iiopxx_check_span(40, _flick_abort198);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t248_switch_tag, unsigned int );
              flick_iiopxx_decode_end_chunk(4);
              switch ((unsigned int )_t248_switch_tag)
                {
                case (unsigned int) 26:
                  {
                    unsigned int _t249_switch_tag;

                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t249_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t249_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t250_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t250_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t250_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t251_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t251_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t251_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t252_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t252_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t252_switch_tag)
                                        {
                                        case /* UNDE */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1431192645):
                                          {
                                            unsigned int _t253_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t253_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t253_switch_tag)
                                              {
                                              case /* RFLO */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1380338767):
                                                {
                                                  unsigned int _t254_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(4);
                                                  flick_cdr_decode_unsigned32(0, _t254_switch_tag, unsigned int );
                                                  flick_iiopxx_decode_end_chunk(4);
                                                  switch ((unsigned int )_t254_switch_tag)
                                                    {
                                                    case /* W:1. */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1463431470):
                                                      {
                                                        unsigned short int _t255_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(2);
                                                        flick_cdr_decode_unsigned16(0, _t255_switch_tag, unsigned short int );
                                                        flick_iiopxx_decode_end_chunk(2);
                                                        switch ((unsigned short int )_t255_switch_tag)
                                                          {
                                                          case /* 0 */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 12288):
                                                            {
                                                              flick_unsigned32_t _t256_temp_string_len;

                                                              _t238_temp_env._id = "IDL:simple3/UNDERFLOW:1.0";
                                                              {
                                                                simple3::UNDERFLOW *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::UNDERFLOW *)new simple3::UNDERFLOW ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort203);
                                                                _t238_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(10);
                                                              flick_cdr_decode_signed32(2, ((simple3::UNDERFLOW *)(_t238_temp_env._user_except))->b, CORBA::Long );
                                                              flick_cdr_decode_unsigned32(6, _t256_temp_string_len, flick_unsigned32_t );
                                                              flick_iiopxx_decode_end_chunk(10);
                                                              flick_iiopxx_decode_end_glob(44);
                                                              flick_iiopxx_decode_new_glob(1 * _t256_temp_string_len);
                                                              flick_iiopxx_check_span(1 * _t256_temp_string_len, _flick_abort203);
                                                              flick_iiopxx_decode_new_chunk(1 * _t256_temp_string_len);
                                                              {
                                                                CORBA::Char *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t256_temp_string_len * sizeof(CORBA::Char )));
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort203);
                                                                ((simple3::UNDERFLOW *)(_t238_temp_env._user_except))->msg.inout() = _t_alloc_ptr;
                                                              }
                                                              flick_cdr_decode_bcopy(0, ((simple3::UNDERFLOW *)(_t238_temp_env._user_except))->msg.inout(), 1 * _t256_temp_string_len);
                                                              flick_iiopxx_decode_end_chunk(1 * _t256_temp_string_len);
                                                              flick_iiopxx_decode_end_glob(1 * _t256_temp_string_len);
                                                              break;
                                                              {
                                                              _flick_abort203:
                                                                goto _flick_abort198;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort198);
                                                              flick_iiopxx_decode_end_glob(44);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort198);
                                                        flick_iiopxx_decode_end_glob(44);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort198);
                                                  flick_iiopxx_decode_end_glob(44);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort198);
                                            flick_iiopxx_decode_end_glob(44);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort198);
                                      flick_iiopxx_decode_end_glob(44);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort198);
                                flick_iiopxx_decode_end_glob(44);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort198);
                          flick_iiopxx_decode_end_glob(44);
                          break;
                        }
                      }
                    break;
                  }
                default:
                  {
                    flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort198);
                    flick_iiopxx_decode_end_glob(44);
                    break;
                  }
                }
              flick_corbaxx_exception_to_env(CORBA::Environment &, _ev, flick_corbaxx_env , _t238_temp_env);
              break;
              {
              _flick_abort198:
                goto _flick_abort157;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort157);
  }
  return _return;
  {
  _flick_abort157:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort156);
  _flick_abort156:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

void simple3::op5(/* simple3 *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();



  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort246);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort246);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort246);
    }




    {
      flick_iiopxx_encode_new_glob(12, _flick_abort246);
      flick_iiopxx_encode_new_chunk(12);
      flick_cdr_encode_unsigned32(0, 4, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '5', flick_char8_t );
      flick_cdr_encode_char8(7, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(12);
      flick_iiopxx_encode_end_glob(12);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort246);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort246);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort246);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort246);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t341_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(40);
        flick_iiopxx_check_span(4, _flick_abort246);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t341_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t341_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(40);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(40);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort281);
              break;
              {
              _flick_abort281:
                goto _flick_abort246;
              }
            }
          default:
            {
              flick_corbaxx_env _t361_temp_env;
              unsigned int _t371_switch_tag;

              flick_iiopxx_check_span(36, _flick_abort282);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t371_switch_tag, unsigned int );
              flick_iiopxx_decode_end_chunk(4);
              switch ((unsigned int )_t371_switch_tag)
                {
                case (unsigned int) 26:
                  {
                    unsigned int _t372_switch_tag;

                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t372_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t372_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t373_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t373_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t373_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t374_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t374_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t374_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t375_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t375_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t375_switch_tag)
                                        {
                                        case /* USER */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1431520594):
                                          {
                                            unsigned int _t376_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t376_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t376_switch_tag)
                                              {
                                              case /* ERRO */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1163022927):
                                                {
                                                  unsigned int _t377_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(4);
                                                  flick_cdr_decode_unsigned32(0, _t377_switch_tag, unsigned int );
                                                  flick_iiopxx_decode_end_chunk(4);
                                                  switch ((unsigned int )_t377_switch_tag)
                                                    {
                                                    case /* R:1. */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1379545390):
                                                      {
                                                        unsigned short int _t378_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(2);
                                                        flick_cdr_decode_unsigned16(0, _t378_switch_tag, unsigned short int );
                                                        flick_iiopxx_decode_end_chunk(2);
                                                        switch ((unsigned short int )_t378_switch_tag)
                                                          {
                                                          case /* 0 */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 12288):
                                                            {
                                                              flick_unsigned32_t _t379_temp_string_len;

                                                              _t361_temp_env._id = "IDL:simple3/USERERROR:1.0";
                                                              {
                                                                simple3::USERERROR *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::USERERROR *)new simple3::USERERROR ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort287);
                                                                _t361_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(6);
                                                              flick_cdr_swap_decode_unsigned32(2, _t379_temp_string_len, flick_unsigned32_t );
                                                              flick_iiopxx_decode_end_chunk(6);
                                                              flick_iiopxx_decode_end_glob(40);
                                                              flick_iiopxx_decode_new_glob(1 * _t379_temp_string_len);
                                                              flick_iiopxx_check_span(1 * _t379_temp_string_len, _flick_abort287);
                                                              flick_iiopxx_decode_new_chunk(1 * _t379_temp_string_len);
                                                              {
                                                                CORBA::Char *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t379_temp_string_len * sizeof(CORBA::Char )));
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort287);
                                                                ((simple3::USERERROR *)(_t361_temp_env._user_except))->reason.inout() = _t_alloc_ptr;
                                                              }
                                                              flick_cdr_swap_decode_bcopy(0, ((simple3::USERERROR *)(_t361_temp_env._user_except))->reason.inout(), 1 * _t379_temp_string_len);
                                                              flick_iiopxx_decode_end_chunk(1 * _t379_temp_string_len);
                                                              flick_iiopxx_decode_end_glob(1 * _t379_temp_string_len);
                                                              break;
                                                              {
                                                              _flick_abort287:
                                                                goto _flick_abort282;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort282);
                                                              flick_iiopxx_decode_end_glob(40);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort282);
                                                        flick_iiopxx_decode_end_glob(40);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort282);
                                                  flick_iiopxx_decode_end_glob(40);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort282);
                                            flick_iiopxx_decode_end_glob(40);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort282);
                                      flick_iiopxx_decode_end_glob(40);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort282);
                                flick_iiopxx_decode_end_glob(40);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort282);
                          flick_iiopxx_decode_end_glob(40);
                          break;
                        }
                      }
                    break;
                  }
                default:
                  {
                    flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort282);
                    flick_iiopxx_decode_end_glob(40);
                    break;
                  }
                }
              flick_corbaxx_exception_to_env(CORBA::Environment &, _ev, flick_corbaxx_env , _t361_temp_env);
              break;
              {
              _flick_abort282:
                goto _flick_abort246;
              }
            }
          }
      }

    else
      {
        int _t302_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(40);
        flick_iiopxx_check_span(4, _flick_abort246);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t302_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t302_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(40);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(40);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort260);
              break;
              {
              _flick_abort260:
                goto _flick_abort246;
              }
            }
          default:
            {
              flick_corbaxx_env _t322_temp_env;
              unsigned int _t332_switch_tag;

              flick_iiopxx_check_span(36, _flick_abort261);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t332_switch_tag, unsigned int );
              flick_iiopxx_decode_end_chunk(4);
              switch ((unsigned int )_t332_switch_tag)
                {
                case (unsigned int) 26:
                  {
                    unsigned int _t333_switch_tag;

                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t333_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t333_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t334_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t334_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t334_switch_tag)
                            {
                            case /* simp */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936289136):
                              {
                                unsigned int _t335_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t335_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t335_switch_tag)
                                  {
                                  case /* le3/ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1818571567):
                                    {
                                      unsigned int _t336_switch_tag;

                                      flick_iiopxx_decode_new_chunk(4);
                                      flick_cdr_decode_unsigned32(0, _t336_switch_tag, unsigned int );
                                      flick_iiopxx_decode_end_chunk(4);
                                      switch ((unsigned int )_t336_switch_tag)
                                        {
                                        case /* USER */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1431520594):
                                          {
                                            unsigned int _t337_switch_tag;

                                            flick_iiopxx_decode_new_chunk(4);
                                            flick_cdr_decode_unsigned32(0, _t337_switch_tag, unsigned int );
                                            flick_iiopxx_decode_end_chunk(4);
                                            switch ((unsigned int )_t337_switch_tag)
                                              {
                                              case /* ERRO */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1163022927):
                                                {
                                                  unsigned int _t338_switch_tag;

                                                  flick_iiopxx_decode_new_chunk(4);
                                                  flick_cdr_decode_unsigned32(0, _t338_switch_tag, unsigned int );
                                                  flick_iiopxx_decode_end_chunk(4);
                                                  switch ((unsigned int )_t338_switch_tag)
                                                    {
                                                    case /* R:1. */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1379545390):
                                                      {
                                                        unsigned short int _t339_switch_tag;

                                                        flick_iiopxx_decode_new_chunk(2);
                                                        flick_cdr_decode_unsigned16(0, _t339_switch_tag, unsigned short int );
                                                        flick_iiopxx_decode_end_chunk(2);
                                                        switch ((unsigned short int )_t339_switch_tag)
                                                          {
                                                          case /* 0 */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 12288):
                                                            {
                                                              flick_unsigned32_t _t340_temp_string_len;

                                                              _t322_temp_env._id = "IDL:simple3/USERERROR:1.0";
                                                              {
                                                                simple3::USERERROR *_t_alloc_ptr;

                                                                _t_alloc_ptr = (simple3::USERERROR *)new simple3::USERERROR ;
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort266);
                                                                _t322_temp_env._user_except = _t_alloc_ptr;
                                                              }
                                                              flick_iiopxx_decode_new_chunk(6);
                                                              flick_cdr_decode_unsigned32(2, _t340_temp_string_len, flick_unsigned32_t );
                                                              flick_iiopxx_decode_end_chunk(6);
                                                              flick_iiopxx_decode_end_glob(40);
                                                              flick_iiopxx_decode_new_glob(1 * _t340_temp_string_len);
                                                              flick_iiopxx_check_span(1 * _t340_temp_string_len, _flick_abort266);
                                                              flick_iiopxx_decode_new_chunk(1 * _t340_temp_string_len);
                                                              {
                                                                CORBA::Char *_t_alloc_ptr;

                                                                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t340_temp_string_len * sizeof(CORBA::Char )));
                                                                if (!_t_alloc_ptr)
                                                                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort266);
                                                                ((simple3::USERERROR *)(_t322_temp_env._user_except))->reason.inout() = _t_alloc_ptr;
                                                              }
                                                              flick_cdr_decode_bcopy(0, ((simple3::USERERROR *)(_t322_temp_env._user_except))->reason.inout(), 1 * _t340_temp_string_len);
                                                              flick_iiopxx_decode_end_chunk(1 * _t340_temp_string_len);
                                                              flick_iiopxx_decode_end_glob(1 * _t340_temp_string_len);
                                                              break;
                                                              {
                                                              _flick_abort266:
                                                                goto _flick_abort261;
                                                              }
                                                            }
                                                          default:
                                                            {
                                                              flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort261);
                                                              flick_iiopxx_decode_end_glob(40);
                                                              break;
                                                            }
                                                          }
                                                        break;
                                                      }
                                                    default:
                                                      {
                                                        flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort261);
                                                        flick_iiopxx_decode_end_glob(40);
                                                        break;
                                                      }
                                                    }
                                                  break;
                                                }
                                              default:
                                                {
                                                  flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort261);
                                                  flick_iiopxx_decode_end_glob(40);
                                                  break;
                                                }
                                              }
                                            break;
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort261);
                                            flick_iiopxx_decode_end_glob(40);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort261);
                                      flick_iiopxx_decode_end_glob(40);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort261);
                                flick_iiopxx_decode_end_glob(40);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort261);
                          flick_iiopxx_decode_end_glob(40);
                          break;
                        }
                      }
                    break;
                  }
                default:
                  {
                    flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort261);
                    flick_iiopxx_decode_end_glob(40);
                    break;
                  }
                }
              flick_corbaxx_exception_to_env(CORBA::Environment &, _ev, flick_corbaxx_env , _t322_temp_env);
              break;
              {
              _flick_abort261:
                goto _flick_abort246;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort246);
  }
  return;
  {
  _flick_abort246:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort245);
  _flick_abort245:
    goto _flick_reaper;
  }

_flick_reaper:
  return;

}

CORBA::Long simple3::op2(/* simple3 *this, */ CORBA::Long a, simple_ptr b, simple2_out c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort291);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort291);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort291);
    }




    {
      flick_iiopxx_encode_new_glob(16, _flick_abort291);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 4, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '2', flick_char8_t );
      flick_cdr_encode_char8(7, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
      flick_cdrxx_encode_IOR(iiopxx, b, 0, simple , _flick_abort291);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort291);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort291);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort291);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort291);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t381_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort291);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t381_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t381_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort304);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swapxx_decode_IOR(iiopxx, c, 1, simple2 , _flick_abort304);
              break;
              {
              _flick_abort304:
                goto _flick_abort291;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort305);
              break;
              {
              _flick_abort305:
                goto _flick_abort291;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort306);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort306:
                goto _flick_abort291;
              }
            }
          }
      }

    else
      {
        int _t380_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort291);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t380_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t380_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort297);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdrxx_decode_IOR(iiopxx, c, 1, simple2 , _flick_abort297);
              break;
              {
              _flick_abort297:
                goto _flick_abort291;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort298);
              break;
              {
              _flick_abort298:
                goto _flick_abort291;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort299);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort299:
                goto _flick_abort291;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort291);
  }
  return _return;
  {
  _flick_abort291:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort290);
  _flick_abort290:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

CORBA::Long simple3::op(/* simple3 *this, */ CORBA::Long a, simple_out b, CORBA::Long &c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Long _return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort308);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort308);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort308);
    }




    {
      flick_iiopxx_encode_new_glob(20, _flick_abort308);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 3, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_cdr_encode_signed32(16, c, CORBA::Long );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort308);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort308);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort308);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort308);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t383_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort308);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t383_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t383_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort321);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swapxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort321);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort321);
              flick_cdr_swap_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort321:
                goto _flick_abort308;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort322);
              break;
              {
              _flick_abort322:
                goto _flick_abort308;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort323);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort323:
                goto _flick_abort308;
              }
            }
          }
      }

    else
      {
        int _t382_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort308);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t382_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t382_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort314);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdrxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort314);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort314);
              flick_cdr_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort314:
                goto _flick_abort308;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort315);
              break;
              {
              _flick_abort315:
                goto _flick_abort308;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort316);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort316:
                goto _flick_abort308;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort308);
  }
  return _return;
  {
  _flick_abort308:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort307);
  _flick_abort307:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

